@@ -1,26 +1,10 @@
-try:
-    import xml.etree.cElementTree as etree
-except ImportError:  # pragma: no cover
-    import xml.etree.ElementTree as etree
-
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.http import HttpResponse
 
-
-try:
-    register_namespace = etree.register_namespace
-except AttributeError:  # pragma: no cover
-    # ElementTree 1.2 (Python 2.6) does not have register_namespace()
-    def register_namespace(prefix, uri):
-        try:
-            etree._namespace_map[uri] = prefix
-        except AttributeError:
-            # cElementTree 1.0.6 (Python 2.6) does not have
-            # register_namespace() or _namespace_map, but
-            # uses ElementTree for serialization
-            import xml.etree.ElementTree as ET
-            ET._namespace_map[uri] = prefix
+from .compat import etree
+from .compat import get_username
+from .compat import register_namespace
 
 
 class CasResponseBase(HttpResponse):
@@ -82,7 +66,7 @@ class ValidationResponse(CasResponseBase):
         if ticket:
             auth_success = etree.SubElement(service_response, self.ns('authenticationSuccess'))
             user = etree.SubElement(auth_success, self.ns('user'))
-            user.text = ticket.user.username
+            user.text = get_username(ticket.user)
             if attributes:
                 for element in self.get_attribute_elements(attributes):
                     auth_success.append(element)
@@ -123,7 +107,7 @@ class ValidationResponse(CasResponseBase):
         </cas:attributes>
         """
         element = etree.Element(self.ns('attributes'))
-        for name, value in attributes:
+        for name, value in attributes.items():
             attr = etree.SubElement(element, self.ns(name))
             attr.text = value
         return [element]
@@ -137,7 +121,7 @@ class ValidationResponse(CasResponseBase):
         <cas:email>ellen@example.com</cas:email>
         """
         elements = []
-        for name, value in attributes:
+        for name, value in attributes.items():
             element = etree.Element(self.ns(name))
             element.text = value
             elements.append(element)
@@ -152,7 +136,7 @@ class ValidationResponse(CasResponseBase):
         <cas:attribute name='email' value='ellen@example.com' />
         """
         elements = []
-        for name, value in attributes:
+        for name, value in attributes.items():
             element = etree.Element(self.ns('attribute'))
             element.set('name', name)
             element.set('value', value)
