@@ -1,61 +1,25 @@
 from __future__ import unicode_literals
 
-try:
-    import xml.etree.cElementTree as etree
-except ImportError:
-    import xml.etree.ElementTree as etree
-
-from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.test import TestCase
+from django.test.utils import override_settings
 
-from mama_cas.compat import get_user_model
+from .factories import ProxyGrantingTicketFactory
+from .factories import ProxyTicketFactory
+from .factories import ServiceTicketFactory
+from .utils import parse
 from mama_cas.exceptions import InvalidTicket
-from mama_cas.models import ProxyGrantingTicket
-from mama_cas.models import ProxyTicket
-from mama_cas.models import ServiceTicket
 from mama_cas.response import ValidationResponse
 from mama_cas.response import ProxyResponse
 
 
-def parse(s, namespace='http://www.yale.edu/tp/cas'):
-    """
-    Parse an XML tree from the given string, removing all
-    of the included namespace strings.
-    """
-    ns = '{%s}' % namespace
-    nsl = len(ns)
-    et = etree.fromstring(s)
-    for elem in et.getiterator():
-        if elem.tag.startswith(ns):
-            elem.tag = elem.tag[nsl:]
-    return et
-
-
 class ValidationResponseTests(TestCase):
     """
     Test the ``ValidationResponse`` XML output.
     """
-    service_url = 'http://www.example.com/'
-    pgt_url = 'https://www.example.com/'
-
     def setUp(self):
-        """
-        Initialize the environment for each test.
-        """
-        user = get_user_model()
-        self.user = user.objects.create_user('ellen',
-                                             password='mamas&papas',
-                                             email='ellen@example.com')
-        self.user.first_name = 'Ellen'
-        self.user.last_name = 'Cohen'
-        self.user.save()
-        self.st = ServiceTicket.objects.create_ticket(service=self.service_url,
-                                                      user=self.user)
-        self.pgt = ProxyGrantingTicket.objects.create_ticket(self.pgt_url,
-                                                             granted_by_st=self.st,
-                                                             validate=False,
-                                                             user=self.user)
+        self.st = ServiceTicketFactory()
+        self.pgt = ProxyGrantingTicketFactory()
 
     def test_validation_response_content_type(self):
         """
@@ -117,16 +81,15 @@ class ValidationResponseTests(TestCase):
         self.assertEqual(proxies[0].text, proxy_list[0])
         self.assertEqual(proxies[1].text, proxy_list[1])
 
+    @override_settings(MAMA_CAS_ATTRIBUTE_FORMAT='jasig')
     def test_validation_response_jasig_attributes(self):
         """
         When given custom user attributes, a ``ValidationResponse``
         should include the attributes in the configured format.
         """
-        attr_format = getattr(settings, 'MAMA_CAS_ATTRIBUTE_FORMAT', 'jasig')
-        settings.MAMA_CAS_ATTRIBUTE_FORMAT = 'jasig'
         attrs = {'givenName': 'Ellen', 'sn': 'Cohen', 'email': 'ellen@example.com'}
         resp = ValidationResponse(context={'ticket': self.st, 'error': None,
-                                           'attributes': attrs.items()},
+                                           'attributes': attrs},
                                   content_type='text/xml')
         attributes = parse(resp.content).find('./authenticationSuccess/attributes')
         self.assertIsNotNone(attributes)
@@ -140,18 +103,15 @@ class ValidationResponseTests(TestCase):
             del attrs[child.tag]
         self.assertEqual(len(attrs), 0)
 
-        settings.MAMA_CAS_ATTRIBUTE_FORMAT = attr_format
-
+    @override_settings(MAMA_CAS_ATTRIBUTE_FORMAT='rubycas')
     def test_validation_response_rubycas_attributes(self):
         """
         When given custom user attributes, a ``ValidationResponse``
         should include the attributes in the configured format.
         """
-        attr_format = getattr(settings, 'MAMA_CAS_ATTRIBUTE_FORMAT', 'jasig')
-        settings.MAMA_CAS_ATTRIBUTE_FORMAT = 'rubycas'
         attrs = {'givenName': 'Ellen', 'sn': 'Cohen', 'email': 'ellen@example.com'}
         resp = ValidationResponse(context={'ticket': self.st, 'error': None,
-                                           'attributes': attrs.items()},
+                                           'attributes': attrs},
                                   content_type='text/xml')
         success = parse(resp.content).find('./authenticationSuccess')
         self.assertIsNotNone(success)
@@ -169,18 +129,15 @@ class ValidationResponseTests(TestCase):
             del attrs[child.tag]
         self.assertEqual(len(attrs), 0)
 
-        settings.MAMA_CAS_ATTRIBUTE_FORMAT = attr_format
-
+    @override_settings(MAMA_CAS_ATTRIBUTE_FORMAT='namevalue')
     def test_validation_response_namevalue_attributes(self):
         """
         When given custom user attributes, a ``ValidationResponse``
         should include the attributes in the configured format.
         """
-        attr_format = getattr(settings, 'MAMA_CAS_ATTRIBUTE_FORMAT', 'jasig')
-        settings.MAMA_CAS_ATTRIBUTE_FORMAT = 'namevalue'
         attrs = {'givenName': 'Ellen', 'sn': 'Cohen', 'email': 'ellen@example.com'}
         resp = ValidationResponse(context={'ticket': self.st, 'error': None,
-                                           'attributes': attrs.items()},
+                                           'attributes': attrs},
                                   content_type='text/xml')
         success = parse(resp.content).find('./authenticationSuccess')
         self.assertIsNotNone(success)
@@ -194,50 +151,27 @@ class ValidationResponseTests(TestCase):
             del attrs[elem.get('name')]
         self.assertEqual(len(attrs), 0)
 
-        settings.MAMA_CAS_ATTRIBUTE_FORMAT = attr_format
-
+    @override_settings(MAMA_CAS_ATTRIBUTE_FORMAT='invalid')
     def test_validation_response_invalid_attribute_format(self):
         """
         Configuring an invalid attribute format should raise an
         ``ImproperlyConfigured`` exception.
         """
-        attr_format = getattr(settings, 'MAMA_CAS_ATTRIBUTE_FORMAT', 'jasig')
-        settings.MAMA_CAS_ATTRIBUTE_FORMAT = 'invalid'
         attrs = {'givenName': 'Ellen', 'sn': 'Cohen', 'email': 'ellen@example.com'}
         with self.assertRaises(ImproperlyConfigured):
             ValidationResponse(context={'ticket': self.st, 'error': None,
-                                        'attributes': attrs.items()},
+                                        'attributes': attrs},
                                content_type='text/xml')
-        settings.MAMA_CAS_ATTRIBUTE_FORMAT = attr_format
 
 
 class ProxyResponseTests(TestCase):
     """
     Test the ``ProxyResponse`` XML output.
     """
-    service_url = 'http://www.example.com/'
-    pgt_url = 'https://www.example.com/'
-
     def setUp(self):
-        """
-        Initialize the environment for each test.
-        """
-        user = get_user_model()
-        self.user = user.objects.create_user('ellen',
-                                             password='mamas&papas',
-                                             email='ellen@example.com')
-        self.user.first_name = 'Ellen'
-        self.user.last_name = 'Cohen'
-        self.user.save()
-        self.st = ServiceTicket.objects.create_ticket(service=self.service_url,
-                                                      user=self.user)
-        self.pgt = ProxyGrantingTicket.objects.create_ticket(self.pgt_url,
-                                                             validate=False,
-                                                             user=self.user,
-                                                             granted_by_st=self.st)
-        self.pt = ProxyTicket.objects.create_ticket(service=self.service_url,
-                                                    user=self.user,
-                                                    granted_by_pgt=self.pgt)
+        self.st = ServiceTicketFactory()
+        self.pgt = ProxyGrantingTicketFactory()
+        self.pt = ProxyTicketFactory()
 
     def test_proxy_response_content_type(self):
         """
