@@ -4,13 +4,13 @@ from django.conf import settings
 from django.contrib import messages
 from django.contrib.auth import login
 from django.http import HttpResponse
-from django.utils.http import urlquote_plus
 from django.utils.translation import ugettext as _
 from django.views.generic import FormView
+from django.views.generic import TemplateView
 from django.views.generic import View
 
+from .compat import get_username
 from mama_cas.forms import LoginForm
-from mama_cas.forms import WarnForm
 from mama_cas.mixins import CasResponseMixin
 from mama_cas.mixins import CustomAttributesMixin
 from mama_cas.mixins import LoginRequiredMixin
@@ -21,6 +21,8 @@ from mama_cas.models import ProxyTicket
 from mama_cas.models import ServiceTicket
 from mama_cas.response import ValidationResponse
 from mama_cas.response import ProxyResponse
+from mama_cas.utils import add_query_params
+from mama_cas.utils import clean_service_url
 from mama_cas.utils import is_valid_service_url
 from mama_cas.utils import redirect
 
@@ -56,7 +58,6 @@ class LoginView(NeverCacheMixin, LogoutUserMixin, FormView):
         service = request.GET.get('service')
         renew = bool(request.GET.get('renew'))
         gateway = bool(request.GET.get('gateway'))
-        warned = request.GET.get('warned')
 
         if renew:
             logger.debug("Renew request received by credential requestor")
@@ -65,12 +66,11 @@ class LoginView(NeverCacheMixin, LogoutUserMixin, FormView):
         elif gateway and service:
             logger.debug("Gateway request received by credential requestor")
             if request.user.is_authenticated():
-                if self.warn_user() and not warned:
-                    return redirect('cas_warn', params={'service': service,
-                                                        'gateway': gateway})
-
                 st = ServiceTicket.objects.create_ticket(service=service,
                                                          user=request.user)
+                if self.warn_user():
+                    return redirect('cas_warn', params={'service': service,
+                                                        'ticket': st.ticket})
                 return redirect(service, params={'ticket': st.ticket})
             else:
                 return redirect(service)
@@ -78,11 +78,11 @@ class LoginView(NeverCacheMixin, LogoutUserMixin, FormView):
             if service:
                 logger.debug("Service ticket request received "
                              "by credential requestor")
-                if self.warn_user() and not warned:
-                    return redirect('cas_warn', params={'service': service})
-
                 st = ServiceTicket.objects.create_ticket(service=service,
                                                          user=request.user)
+                if self.warn_user():
+                    return redirect('cas_warn', params={'service': service,
+                                                        'ticket': st.ticket})
                 return redirect(service, params={'ticket': st.ticket})
             else:
                 msg = _("You are logged in as %s") % request.user
@@ -134,7 +134,7 @@ class LoginView(NeverCacheMixin, LogoutUserMixin, FormView):
         if form.cleaned_data.get('warn'):
             self.request.session['warn'] = True
 
-        service = form.cleaned_data.get('service')
+        service = self.request.GET.get('service')
         if service:
             st = ServiceTicket.objects.create_ticket(service=service,
                                                      user=self.request.user,
@@ -142,40 +142,25 @@ class LoginView(NeverCacheMixin, LogoutUserMixin, FormView):
             return redirect(service, params={'ticket': st.ticket})
         return redirect('cas_login')
 
-    def get_initial(self):
-        service = self.request.GET.get('service')
-        if service:
-            return {'service': urlquote_plus(service)}
 
-
-class WarnView(NeverCacheMixin, LoginRequiredMixin, FormView):
+class WarnView(NeverCacheMixin, LoginRequiredMixin, TemplateView):
     """
     (2.2.1) Disables transparent authentication by informing the user
     that service authentication is taking place. The user can choose
     to continue or cancel the authentication attempt.
     """
     template_name = 'mama_cas/warn.html'
-    form_class = WarnForm
 
-    def form_valid(self, form):
-        service = form.cleaned_data.get('service')
-        gateway = bool(form.cleaned_data.get('gateway'))
-        return redirect('cas_login', params={'service': service,
-                                             'gateway': gateway,
-                                             'warned': 'true'})
-
-    def get_initial(self):
-        initial = {}
-        service = self.request.GET.get('service')
-        gateway = bool(self.request.GET.get('gateway'))
-        if service:
-            initial['service'] = urlquote_plus(service)
-        if gateway:
-            initial['gateway'] = gateway
-        return initial
+    def get(self, request, *args, **kwargs):
+        service = request.GET.get('service')
+        ticket = request.GET.get('ticket')
+        msg = _("Do you want to access %s as %s?") % (clean_service_url(service),
+                                                      request.user)
+        messages.info(request, msg)
+        kwargs['service'] = add_query_params(service, {'ticket': ticket})
+        return super(WarnView, self).get(request, *args, **kwargs)
 
     def get_context_data(self, **kwargs):
-        kwargs['service'] = self.request.GET.get('service')
         return kwargs
 
 
@@ -221,7 +206,7 @@ class ValidateView(NeverCacheMixin, ValidateTicketMixin, View):
     def get(self, request, *args, **kwargs):
         st, pgt, error = self.validate_service_ticket(request)
         if st:
-            content = "yes\n%s\n" % st.user.username
+            content = "yes\n%s\n" % get_username(st.user)
         else:
             content = "no\n\n"
         return HttpResponse(content=content, content_type='text/plain')
@@ -283,11 +268,10 @@ class ProxyValidateView(NeverCacheMixin, ValidateTicketMixin,
             # If no ticket parameter is present, attempt to validate it
             # anyway so the appropriate error is raised
             t, pgt, proxies, error = self.validate_proxy_ticket(self.request)
-            attributes = self.get_custom_attributes(t)
         else:
             t, pgt, error = self.validate_service_ticket(self.request)
             proxies = None
-            attributes = self.get_custom_attributes(t)
+        attributes = self.get_custom_attributes(t)
         return {'ticket': t, 'pgt': pgt, 'proxies': proxies,
                 'error': error, 'attributes': attributes}
 
